import { ReadableStream, WritableStream } from "web-streams-polyfill";
/** Represents a file being read from the cache. */
export declare class CacheRead {
    #private;
    /**
     * Gets a readable stream to read the cached contents in a streaming fashion.
     */
    get stream(): ReadableStream;
    /** Returns whether the stream property was already accessed. */
    get streamUsed(): boolean;
    /** Reads the cached document to an ArrayBuffer. */
    arrayBuffer(): Promise<ArrayBuffer>;
    /** Reads the cached document to a string. The text is decoded using UTF-8. */
    text(): Promise<string>;
}
/** Represents a file being written to the cache. */
export declare class CacheWrite {
    #private;
    /**
     * Gets a writable stream that can be used to write data to the cache in a streaming
     * fashion.
     *
     * Can only be accessed once.
     */
    get stream(): WritableStream;
    /** Returns whether the stream property was already accessed. */
    get streamUsed(): boolean;
    /**
     * Gets the cache document size limit. Attempting to write a document longer than
     * this will throw an exception.
     */
    get sizeLimit(): number;
    /**
     * Writes the given value to this document.
     *
     * ArrayBuffers are written verbatim. Strings are written with UTF-8 encoding.
     */
    write(value: ArrayBuffer | ArrayBufferView | string): Promise<void>;
}
export declare type CacheApi = typeof cacheApi;
/**
 * Enables operations on the local document cache
 *
 * This cache allows Edge Handlers to cache expensive operations, like page templating.
 * The cache is available on each CDN node, but it is not distributed. A value set on
 * one node will not be propagated to other nodes.
 */
export declare const cacheApi: Readonly<{
    /**
     * Retrieves a cached document. Returns `null` when the document cannot be found.
     *
     * @param key Name of the key to retrieve. Scoped to the site.
     */
    getDocument: (key: string) => Promise<CacheRead | null>;
    /**
     * Writes a document to the given cache key.
     *
     * @param key Name of the key to retrieve. Scoped to the site.
     */
    setDocument: (key: string) => Promise<CacheWrite>;
    /**
     * Removes a cached document if it exists.
     *
     * Does not throw if called on a nonexistent document.
     *
     * @param key Name of the key to retrieve. Scoped to the site.
     */
    removeDocument: (key: string) => Promise<void>;
}>;
